@@ -179,7 +179,7 @@ int cifs_statfs(struct super_block *sb, struct statfs *buf)
 {
 	int xid, rc;
 	struct cifs_sb_info *cifs_sb;
-	struct smbTconInfo *pTcon;
+	struct cifsTconInfo *pTcon;
 
 	xid = GetXid();
 
@@ -254,7 +254,7 @@ static struct super_block *cifs_get_sb(struct file_system_type *fs_type,
 				       int flags, char *dev_name,
 				       void *data)
 {
-    cFYI(1,("\nDevname: %s flags: %d ",dev_name,flags));
+	cFYI(1, ("\nDevname: %s flags: %d ", dev_name, flags));
 	return get_sb_nodev(fs_type, flags, data, cifs_read_super);
 }
 
