@@ -71,16 +71,13 @@
 /*
  * CIFS vfs client Status information (based on what we know.)
  */
+
+ /* associated with each tcp and smb session */
 enum statusEnum {
 	CifsNew = 0,
 	CifsGood,
-	CifsDying
-};
-
-enum failureFlagval {
-	FailNone,		/* No failure    */
-	FailDying,		/* Failure - hangup required */
-	FailDead		/* Failure - no hangup required */
+	CifsExiting,
+	CifsNeedReconnect
 };
 
 
@@ -98,21 +95,16 @@ struct TCP_Server_Info {
 	struct sockaddr_in sockAddr;
 	wait_queue_head_t response_q;
 	struct list_head pending_mid_q;
-	enum statusEnum fsStatus;	/* what WE think the status is           */
 	void *Server_NlsInfo;	/* BB - placeholder for future NLS info  */
 	unsigned short server_codepage;	/* codepage for the server    */
 	unsigned long ip_address;	/* IP addr for the server if known     */
 	unsigned long svType;	/* computer type                       */
 	char versionMajor;
 	char versionMinor;
-	int svStatus:1;		/* server Status: 1 is good                            */
-	/* nothing ever gets deleted from the server list once */
-	/* its added since there could be sessions that have a */
-	/* pointer to this data.   So, they just get marked bad */
-	int svNewStatus:1;	/* NewStatus on refresh server list: 1 is good       */
-	int svlocal:1;		/* local server or remote                            */
-	int socketUseCount;	/* indicates if the server has any open              */
-	/* sessions on it                                    */
+	int svlocal:1;		/* local server or remote */
+	atomic_t socketUseCount;	/* indicates if the server has any open cifs sessions */
+	enum statusEnum tcpStatus;	/* what we think the status is */
+	struct semaphore tcpSem;
 	struct task_struct *tsk;
 };
 
@@ -121,12 +113,11 @@ struct TCP_Server_Info {
  * and name. We always get the password on the fly in case it
  * has changed. We also hang a list of sessions owned by this user off here. 
  */
-struct smbUidInfo {
-	struct smbUidInfo *next1;	/* BB replace with list and atomicize */
-	struct smbSesInfo *ses;	/* list of sessions *//* BB replace with list and atomicize */
-	struct srSesInfo *sesSR;	/* Save/Restore session list @D2 */
-/*    MutexT sesLock;  *//* session lsit lock *//* BB fix consistent with other structs */
-	unsigned int id;	/* uid */
+struct cifsUidInfo {
+	struct cifsUidInfo *next1;	/* BB replace with list and atomicize */
+	struct cifsSesInfo *ses;	/* list of sessions *//* BB replace with list and atomicize */
+	struct srSesInfo *sesSR;	/* Save/Restore session list */
+	uid_t linux_uid;
 	char user[MAX_USERNAME_SIZE + 1];	/* ascii name of user */
 	/* BB eventually need ptr into PAM or WinBind info */
 };
@@ -134,29 +125,26 @@ struct smbUidInfo {
 /*
  * Session structure.  One of these for each uid session with a particular host
  */
-struct smbSesInfo {
-	struct list_head smbSessionList;
+struct cifsSesInfo {
+	struct list_head cifsSessionList;
 	struct semaphore sesSem;
-	struct smbUidInfo *uidInfo;	/* pointer to user info */
+	struct cifsUidInfo *uidInfo;	/* pointer to user info */
 	struct TCP_Server_Info *server;	/* pointer to server info */
 	atomic_t inUse;		/* # of CURRENT users of this ses */
-	enum failureFlagval failureFlag;	/* If this session has failed */
+	enum statusEnum status;
 	int dialectIndex;	/* the negotiated dialect index */
 	char secMode;
-	int maxReq;		/* Clients should submit no more */
-	/* than maxReq distinct unanswered */
-	/* SMBs to the server when using  */
+	unsigned int maxReq;	/* Clients should submit no more */
+	/* than maxReq distinct unanswered SMBs to the server when using  */
 	/* multiplexed reads or writes */
-	int maxBuf;		/* maxBuf specifies the maximum */
-	/* message size the server can */
-	/* send or receive for non-raw SMBs */
-	int maxRw;		/* maxRw specifies the maximum */
-	/* message size the server can */
-	/* send or receive for */
-	/* SMB_COM_WRITE_RAW or */
-	/* SMB_COM_READ_RAW. */
+	unsigned int maxBuf;	/* maxBuf specifies the maximum */
+	/* message size the server can send or receive for non-raw SMBs */
+	unsigned int maxRw;	/* maxRw specifies the maximum */
+	/* message size the server can send or receive for */
+	/* SMB_COM_WRITE_RAW or SMB_COM_READ_RAW. */
 	char sessid[4];		/* unique token id for this session */
 	/* (returned on Negotiate */
+	__u16 ipc_tid;		/* special tid for connection to IPC share */
 	int capabilities;
 	__u16 timeZone;
 	char *serverOS;		/* name of operating system underlying the server */
@@ -164,17 +152,17 @@ struct smbSesInfo {
 	char *serverDomain;	/* security realm of server */
 	int Suid;		/* needed for user level security */
 	char serverName[SERVER_NAME_LEN_WITH_NULL * 2];	/* BB make bigger for tcp names - will ipv6 and sctp addresses fit here?? */
-	char userName[MAX_USERNAME_SIZE + 1];	/* BB remove and replace with list of smbUidInfo structures */
+	char userName[MAX_USERNAME_SIZE + 1];	/* BB remove and replace with list of cifsUidInfo structures */
 };
 
 /*
  * there is one of these for each connection to a resource on a particular
  * session 
  */
-struct smbTconInfo {
-	struct list_head smbConnectionList;
+struct cifsTconInfo {
+	struct list_head cifsConnectionList;
 	struct semaphore tconSem;
-	struct smbSesInfo *ses;	/* pointer to session associated with */
+	struct cifsSesInfo *ses;	/* pointer to session associated with */
 	char treeName[MAX_TREE_SIZE + 1];	/* The ascii or unicode name of this resource depending on the ses->capabilities *//* BB fill in this field */
 	char *nativeFileSystem;
 	__u16 tid;		/* The 2 byte transaction id */
@@ -190,10 +178,11 @@ struct smbTconInfo {
  * This info hangs off the cifsFileInfo structure.  This is used to track
  * byte stream locks on the file
  */
-struct smbLockInfo {
-	struct smbLockInfo *next;
+struct cifsLockInfo {
+	struct cifsLockInfo *next;
 	int start;
 	int length;
+	int type;
 };
 
 /*
@@ -216,7 +205,7 @@ struct cifsFileInfo {
  */
 
 struct cifsInodeInfo {
-	struct smbLockInfo *lockList;	/* BB replace with list and atomicize */
+	struct cifsLockInfo *lockList;	/* BB replace with list and atomicize */
 	__u32 cifsAttrs;	/* e.g. DOS archive bit, sparse, compressed, system etc. */
 	atomic_t inUse;		/* num concurrent users (local openers cifs) of file */
 	unsigned long time;	/* jiffies of last update/check of inode */
@@ -231,7 +220,7 @@ struct mid_q_entry {
 	__u16 pid;		/* process id */
 	__u16 command;		/* smb command code */
 	struct timeval when_sent;	/* time when smb sent */
-	struct smbSesInfo *ses;	/* smb was sent to this server */
+	struct cifsSesInfo *ses;	/* smb was sent to this server */
 	struct task_struct *tsk;	/* task waiting for response */
 	struct smb_hdr *resp_buf;	/* response buffer */
 };
