@@ -290,22 +290,23 @@
 #pragma pack(1)
 
 typedef struct smb_hdr {
-	__u32 smb_buf_length;	/* BB length is only two or three bytes - with one or two byte type preceding it but that is always zero - we could mask the type byte off just in case BB */
+	__u32 smb_buf_length;	/* big endian on wire *//* BB length is only two or three bytes - with one or two byte type preceding it but that is always zero - we could mask the type byte off just in case BB */
 	__u8 Protocol[4];
 	__u8 Command;
 	union {
 		struct {
 			__u8 ErrorClass;
 			__u8 Reserved;
-			__u16 Error;
+			__u16 Error;	/* note: treated as little endian (le) on wire */
 		} DosError;
-		__u32 CifsError;
+		__u32 CifsError;	/* note: le */
 	} Status;
 	__u8 Flags;
-	__u16 Flags2;
-	__u8 pad[12];
+	__u16 Flags2;		/* note: le */
+	__u16 PidHigh;		/* note: le */
+	__u8 pad[10];
 	__u16 Tid;
-	__u16 Pid;
+	__u16 Pid;		/* note: le */
 	__u16 Uid;
 	__u16 Mid;
 	__u8 WordCount;
@@ -578,6 +579,11 @@ typedef struct smb_com_close_rsp {
 	__u16 ByteCount;	/* bct = 0 */
 } CLOSE_RSP;
 
+/* OpenFlags */
+#define REQ_OPLOCK         0x00000002
+#define REQ_BATCHOPLOCK    0x00000004
+#define REQ_OPENDIRONLY    0x00000008
+
 typedef struct smb_com_open_req {	/* also handles create */
 	SMB_HDR hdr;		/* wct = 24 */
 	__u8 AndXCommand;
@@ -1424,12 +1430,10 @@ typedef struct {
 
 typedef struct {
 	__u64 AllocationSize;
-
 } FILE_ALLOCATION_INFO;		/* size info, level 0x103 */
 
 typedef struct {
 	__u64 FileSize;		/* offset to end of file */
-
 } FILE_END_OF_FILE_INFO;	/* size info, level 0x104 */
 
 typedef struct {
@@ -1470,87 +1474,6 @@ typedef struct {
 	FEA list[1];
 } FEALIST;
 
-/*
- * Our resume information (used on readdir() calls) to resume half way
- * through a directory
- */
-
-struct resumeCursor {
-	struct resumeCursor *next;
-	unsigned int resumeKey;
-	unsigned int svrResumeKey;
-	char lastName[MAX_PATHCONF];
-};
-
 #pragma pack()			/* resume default structure packing */
 
-/*
- * Our directory open structure (that we allocate on an OPENDIR call
- */
-struct dirOpen {
-	struct dirOpen *next;
-	struct smbUidInfo *user;
-	unsigned short handle;
-	struct smbTconInfo *tcon;
-	struct DirChild *server;
-	char shareName[(SNLEN * 2) + 2];
-	int inUse;
-};
-
-/*
- * Flags we maintain about files/directories the File Attributes Fields
- *  are there more fields that NT supports ??? that we should set ???
- */
-struct commonFlags {
-	int remote:1;		/* if is local or remote on system */
-	int savable:1;		/* if this should be savable */
-	int driveletter:1;	/* if this is a drive letter root */
-};
-/*
- * Cached data (whole structure)
- */
-struct commonCache {
-	int finfoCache:1;
-	int codepageCache:1;
-	FILE_ALL_INFO finfo;
-	unsigned short codepage;
-	unsigned int finfoTime;
-	unsigned int codepageTime;
-};
-
-/*
- * Common data we assocoate with every file or directory we have a vnode
- * for
- */
-struct commonData {		/* we will store fullname and shareName in unicode now */
-	char *fullname;
-	char shareName[(SNLEN * 2) + 2];
-	struct DirChild *server;
-	struct vnode *vpParent;
-	/* BB add nlsInfo; */
-	int fid;
-	struct commonFlags flags;
-	struct commonCache cacheData;	/* @A8A */
-};
- /*
-  * Data we keep for every directory we have a vnode for
-  */
-struct commonDir {
-	struct commonData common;
-	/* BB add mutex */
-	struct DirChild *children;
-	struct dirOpen *opens;
-	int currResumeKey;
-	struct resumeCursor *cursors;
-};
-
-/*
- * Data we keep for every file we have a node for
- */
-struct commonFile {
-	struct commonData common;
-	struct smbFileInfo *opens;
-	/* BB add mutex */
-};
-
 #endif				/* _CIFSPDU_H */
