@@ -40,7 +40,7 @@ extern char *build_path_from_dentry(struct dentry *);
 extern char *build_wildcard_path_from_dentry(struct dentry *direntry);
 extern void renew_parental_timestamps(struct dentry *direntry);
 extern void *kcalloc(size_t mem, int type);
-extern int SendReceive(const unsigned int /* xid */ , struct smbSesInfo *,
+extern int SendReceive(const unsigned int /* xid */ , struct cifsSesInfo *,
 		       struct smb_hdr * /* input */ ,
 		       struct smb_hdr * /* out */ ,
 		       int * /* bytes returned */ , const int long_op);
@@ -49,7 +49,7 @@ extern int checkSMB(struct smb_hdr *smb, __u16 mid, int length);
 extern int smbCalcSize(struct smb_hdr *ptr);
 extern int map_smb_to_linux_error(struct smb_hdr *smb);
 extern void header_assemble(struct smb_hdr *, char /* command */ ,
-			    const struct smbTconInfo *, int
+			    const struct cifsTconInfo *, int
 			    /* length of fixed section (word count) in two byte units  */
     );
 extern time_t cifs_NTtimeToUnix(u64 /* utc nanoseconds since 1601 */ );
@@ -67,131 +67,136 @@ extern int cifs_get_inode_info_unix(struct inode **pinode,
 				    const unsigned char *search_path,
 				    struct super_block *sb);
 
-extern int CIFSSMBNegotiate(unsigned int xid, struct smbSesInfo *ses,
+extern int CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses,
 			    char cryptokey[CIFS_CRYPTO_KEY_SIZE]);
-extern int CIFSSMBSessSetup(unsigned int xid, struct smbSesInfo *ses,
+extern int CIFSSMBSessSetup(unsigned int xid, struct cifsSesInfo *ses,
 			    char *user, char *domain,
 			    char session_key[CIFS_SESSION_KEY_SIZE],
 			    char session_key2[CIFS_SESSION_KEY_SIZE],
 			    const struct nls_table *);
-extern int CIFSSMBTCon(unsigned int xid, struct smbSesInfo *ses,
-		       const char *tree, struct smbTconInfo *tcon,
+extern int CIFSSMBTCon(unsigned int xid, struct cifsSesInfo *ses,
+		       const char *tree, struct cifsTconInfo *tcon,
 		       const struct nls_table *);
 
-extern int CIFSFindFirst(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSFindFirst(const int xid, const struct cifsTconInfo *tcon,
 			 const char *searchName,
 			 FILE_DIRECTORY_INFO * findData,
 			 T2_FFIRST_RSP_PARMS * findParms,
 			 const struct nls_table *nls_codepage,
 			 int *pUnicodeFlag,
 			 int *pUnixFlag /* if Unix extensions used */ );
-extern int CIFSFindNext(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 			FILE_DIRECTORY_INFO * findData,
 			T2_FNEXT_RSP_PARMS * findParms,
 			const __u16 searchHandle, const __u32 resumeKey,
 			int *UnicodeFlag, int *pUnixFlag);
 
-extern int CIFSSMBQPathInfo(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 			    const unsigned char *searchName,
 			    FILE_ALL_INFO * findData,
 			    const struct nls_table *nls_codepage);
 
 extern int CIFSSMBUnixQPathInfo(const int xid,
-				const struct smbTconInfo *tcon,
+				const struct cifsTconInfo *tcon,
 				const unsigned char *searchName,
 				FILE_UNIX_BASIC_INFO * pFindData,
 				const struct nls_table *nls_codepage);
 
-extern int CIFSGetDFSRefer(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSGetDFSRefer(const int xid, struct cifsSesInfo *ses,
 			   const unsigned char *searchName,
 			   unsigned char **targetUNCs,
 			   int *number_of_UNC_in_array,
 			   const struct nls_table *nls_codepage);
 
-extern int CIFSSMBQFSInfo(const int xid, const struct smbTconInfo *tcon,
+extern int connect_to_dfs_path(int xid, struct cifsSesInfo *pSesInfo,
+			       const char *old_path,
+			       const struct nls_table *nls_codepage);
+
+extern int CIFSSMBQFSInfo(const int xid, const struct cifsTconInfo *tcon,
 			  struct statfs *FSData,
 			  const struct nls_table *nls_codepage);
-extern int CIFSSMBQFSAttributeInfo(const int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBQFSAttributeInfo(const int xid,
+				   struct cifsTconInfo *tcon,
 				   const struct nls_table *nls_codepage);
-extern int CIFSSMBQFSDeviceInfo(const int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBQFSDeviceInfo(const int xid, struct cifsTconInfo *tcon,
 				const struct nls_table *nls_codepage);
-extern int CIFSSMBQFSUnixInfo(const int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBQFSUnixInfo(const int xid, struct cifsTconInfo *tcon,
 			      const struct nls_table *nls_codepage);
 
-extern int CIFSSMBSetTimes(const int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBSetTimes(const int xid, struct cifsTconInfo *tcon,
 			   char *fileName, FILE_BASIC_INFO * data,
 			   const struct nls_table *nls_codepage);
-extern int CIFSSMBSetEOF(const int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBSetEOF(const int xid, struct cifsTconInfo *tcon,
 			 char *fileName, __u64 size,
 			 const struct nls_table *nls_codepage);
 extern int CIFSSMBSetAllocationSize(const int xid,
-				    struct smbTconInfo *tcon,
+				    struct cifsTconInfo *tcon,
 				    char *fileName, __u64 size,
 				    const struct nls_table *nls_codepage);
-extern int CIFSSMBUnixSetPerms(const int xid, struct smbTconInfo *pTcon,
+extern int CIFSSMBUnixSetPerms(const int xid, struct cifsTconInfo *pTcon,
 			       char *full_path, __u64 mode, __u64 uid,
 			       __u64 gid,
 			       const struct nls_table *nls_codepage);
 
-extern int CIFSSMBMkDir(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBMkDir(const int xid, const struct cifsTconInfo *tcon,
 			const char *newName,
 			const struct nls_table *nls_codepage);
-extern int CIFSSMBRmDir(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBRmDir(const int xid, const struct cifsTconInfo *tcon,
 			const char *name,
 			const struct nls_table *nls_codepage);
 
-extern int CIFSSMBDelFile(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBDelFile(const int xid, const struct cifsTconInfo *tcon,
 			  const char *name,
 			  const struct nls_table *nls_codepage);
-extern int CIFSSMBRename(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBRename(const int xid, const struct cifsTconInfo *tcon,
 			 const char *fromName, const char *toName,
 			 const struct nls_table *nls_codepage);
 extern int CIFSCreateHardLink(const int xid,
-			      const struct smbTconInfo *tcon,
+			      const struct cifsTconInfo *tcon,
 			      const char *fromName, const char *toName,
 			      const struct nls_table *nls_codepage);
 extern int CIFSUnixCreateHardLink(const int xid,
-				  const struct smbTconInfo *tcon,
+				  const struct cifsTconInfo *tcon,
 				  const char *fromName, const char *toName,
 				  const struct nls_table *nls_codepage);
 extern int CIFSUnixCreateSymLink(const int xid,
-				 const struct smbTconInfo *tcon,
+				 const struct cifsTconInfo *tcon,
 				 const char *fromName, const char *toName,
 				 const struct nls_table *nls_codepage);
 extern int CIFSSMBUnixQuerySymLink(const int xid,
-				   const struct smbTconInfo *tcon,
+				   const struct cifsTconInfo *tcon,
 				   const unsigned char *searchName,
 				   char *syminfo, const int buflen,
 				   const struct nls_table *nls_codepage);
 
-extern int CIFSSMBOpen(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBOpen(const int xid, const struct cifsTconInfo *tcon,
 		       const char *fileName, const int disposition,
 		       const int access_flags, const int omode,
 		       __u16 * netfid, int *pOplock,
 		       const struct nls_table *nls_codepage);
-extern int CIFSSMBClose(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBClose(const int xid, const struct cifsTconInfo *tcon,
 			const int smb_file_id);
 
-extern int CIFSSMBRead(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBRead(const int xid, const struct cifsTconInfo *tcon,
 		       const int netfid, unsigned int count,
 		       const __u64 lseek, unsigned int *nbytes, char *buf);
-extern int CIFSSMBWrite(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBWrite(const int xid, const struct cifsTconInfo *tcon,
 			const int netfid, const unsigned int count,
 			const __u64 lseek, unsigned int *nbytes,
 			const char *buf, const int long_op);
-extern int CIFSSMBLock(const int xid, const struct smbTconInfo *tcon,
+extern int CIFSSMBLock(const int xid, const struct cifsTconInfo *tcon,
 		       const __u16 netfid, const __u64 len,
 		       const __u64 offset, const __u32 numUnlock,
 		       const __u32 numLock, const __u32 lockType,
 		       const int waitFlag);
 
-extern int CIFSSMBTDis(const int xid, struct smbTconInfo *tcon);
-extern int CIFSSMBLogoff(const int xid, struct smbSesInfo *ses);
+extern int CIFSSMBTDis(const int xid, struct cifsTconInfo *tcon);
+extern int CIFSSMBLogoff(const int xid, struct cifsSesInfo *ses);
 
-extern struct smbSesInfo *sesInfoAlloc(void);
-extern void sesInfoFree(struct smbSesInfo *);
-extern struct smbTconInfo *tconInfoAlloc(void);
-extern void tconInfoFree(struct smbTconInfo *);
+extern struct cifsSesInfo *sesInfoAlloc(void);
+extern void sesInfoFree(struct cifsSesInfo *);
+extern struct cifsTconInfo *tconInfoAlloc(void);
+extern void tconInfoFree(struct cifsTconInfo *);
 
 extern int cifs_demultiplex_thread(struct TCP_Server_Info *);
 
@@ -201,33 +206,33 @@ extern int cifs_demultiplex_thread(struct TCP_Server_Info *);
 extern int CIFSBuildServerList(int xid, char *serverBufferList,
 			       int recordlength, int *entries,
 			       int *totalEntries, int *topoChangedFlag);
-extern int CIFSSMBQueryShares(int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBQueryShares(int xid, struct cifsTconInfo *tcon,
 			      shareInfo * shareList, int bufferLen,
 			      int *entries, int *totalEntries);
-extern int CIFSSMBQueryAlias(int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBQueryAlias(int xid, struct cifsTconInfo *tcon,
 			     aliasInfo * aliasList, int bufferLen,
 			     int *entries, int *totalEntries);
-extern int CIFSSMBAliasInfo(int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBAliasInfo(int xid, struct cifsTconInfo *tcon,
 			    char *aliasName, char *serverName,
 			    char *shareName, char *comment);
-extern int CIFSSMBGetShareInfo(int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBGetShareInfo(int xid, struct cifsTconInfo *tcon,
 			       char *share, char *comment);
-extern int CIFSSMBGetUserPerms(int xid, struct smbTconInfo *tcon,
+extern int CIFSSMBGetUserPerms(int xid, struct cifsTconInfo *tcon,
 			       char *userName, char *searchName,
 			       int *perms);
-extern int CIFSSMBSync(int xid, struct smbTconInfo *tcon, int netfid,
+extern int CIFSSMBSync(int xid, struct cifsTconInfo *tcon, int netfid,
 		       int pid);
 
 extern int CIFSSMBSeek(int xid,
-		       struct smbTconInfo *tcon,
+		       struct cifsTconInfo *tcon,
 		       int netfid,
 		       int pid,
 		       int whence,
 		       unsigned long offset, long long *newoffset);
 
 extern int CIFSSMBCopy(int xid,
-		       struct smbTconInfo *ftcon,
+		       struct cifsTconInfo *ftcon,
 		       char *fromName,
-		       struct smbTconInfo *ttcon,
+		       struct cifsTconInfo *ttcon,
 		       char *toName, int ofun, int flags);
 #endif				/* _CIFSPROTO_H */
