@@ -40,7 +40,7 @@ static struct {
 	BAD_PROT, "\2"}
 };
 
-int smb_init(int smb_command, int wct, const struct smbTconInfo *tcon,
+int smb_init(int smb_command, int wct, const struct cifsTconInfo *tcon,
 	     void **request_buf /* returned */ ,
 	     void **response_buf /* returned */ )
 {
@@ -61,7 +61,7 @@ int smb_init(int smb_command, int wct, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBNegotiate(unsigned int xid, struct smbSesInfo *ses,
+int CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses,
 		     char cryptokey[CIFS_CRYPTO_KEY_SIZE])
 {
 	NEGOTIATE_REQ *pSMB;
@@ -105,6 +105,7 @@ int CIFSSMBNegotiate(unsigned int xid, struct smbSesInfo *ses,
 		    min(le32_to_cpu(pSMBr->MaxBufferSize),
 			(__u32) CIFS_MAX_MSGSIZE + MAX_CIFS_HDR_SIZE);
 		ses->maxRw = le32_to_cpu(pSMBr->MaxRawSize);	/* BB le_to_host needed around here and ff */
+		cFYI(1, ("\nMax buf = %d ", ses->maxBuf));
 		GETU32(ses->sessid) = le32_to_cpu(pSMBr->SessionKey);
 		ses->capabilities = le32_to_cpu(pSMBr->Capabilities);
 		ses->timeZone = le16_to_cpu(pSMBr->ServerTimeZone);
@@ -122,7 +123,7 @@ int CIFSSMBNegotiate(unsigned int xid, struct smbSesInfo *ses,
 	return rc;
 }
 
-int CIFSSMBTDis(const int xid, struct smbTconInfo *tcon)
+int CIFSSMBTDis(const int xid, struct cifsTconInfo *tcon)
 {
 	struct smb_hdr *smb_buffer;
 	struct smb_hdr *smb_buffer_response;
@@ -171,7 +172,7 @@ int CIFSSMBTDis(const int xid, struct smbTconInfo *tcon)
 	return rc;
 }
 
-int CIFSSMBLogoff(const int xid, struct smbSesInfo *ses)
+int CIFSSMBLogoff(const int xid, struct cifsSesInfo *ses)
 {
 	struct smb_hdr *smb_buffer_response;
 	LOGOFF_ANDX_REQ *pSMB;
@@ -181,7 +182,7 @@ int CIFSSMBLogoff(const int xid, struct smbSesInfo *ses)
 	cFYI(1, ("\nIn SMBLogoff for session disconnect"));
 
 	if (ses)
-		down(&ses->sesSem);
+		down(&ses->sesSem);	/* need to add more places where this sem is checked */
 	else
 		return -EIO;
 
@@ -204,7 +205,11 @@ int CIFSSMBLogoff(const int xid, struct smbSesInfo *ses)
 
 	rc = SendReceive(xid, ses, (struct smb_hdr *) pSMB,
 			 smb_buffer_response, &length, 0);
-
+	if (ses->server) {
+		atomic_dec(&ses->server->socketUseCount);
+		if (atomic_read(&ses->server->socketUseCount) == 0)
+			ses->server->tcpStatus = CifsExiting;
+	}
 	if (pSMB)
 		buf_release(pSMB);
 	if (smb_buffer_response)
@@ -213,7 +218,7 @@ int CIFSSMBLogoff(const int xid, struct smbSesInfo *ses)
 	return rc;
 }
 
-int CIFSSMBDelFile(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBDelFile(const int xid, const struct cifsTconInfo *tcon,
 		   const char *fileName,
 		   const struct nls_table *nls_codepage)
 {
@@ -259,7 +264,7 @@ int CIFSSMBDelFile(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBRmDir(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBRmDir(const int xid, const struct cifsTconInfo *tcon,
 		 const char *dirName, const struct nls_table *nls_codepage)
 {
 	DELETE_DIRECTORY_REQ *pSMB = NULL;
@@ -305,7 +310,7 @@ int CIFSSMBRmDir(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBMkDir(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBMkDir(const int xid, const struct cifsTconInfo *tcon,
 		 const char *name, const struct nls_table *nls_codepage)
 {
 	int rc = 0;
@@ -354,7 +359,7 @@ int CIFSSMBMkDir(const int xid, const struct smbTconInfo *tcon,
 
 /* BB Need to continue endian neutral code fixing from here down and in SessSetup and tConx */
 
-int CIFSSMBOpen(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBOpen(const int xid, const struct cifsTconInfo *tcon,
 		const char *fileName, const int openDisposition,
 		const int access_flags, const int omode, __u16 * netfid,
 		int *pOplock, const struct nls_table *nls_codepage)
@@ -428,7 +433,7 @@ int CIFSSMBOpen(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBRead(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBRead(const int xid, const struct cifsTconInfo *tcon,
 		const int netfid, const unsigned int count,
 		const __u64 lseek, unsigned int *nbytes, char *buf)
 {
@@ -483,7 +488,7 @@ int CIFSSMBRead(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBWrite(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBWrite(const int xid, const struct cifsTconInfo *tcon,
 		 const int netfid, const unsigned int count,
 		 const __u64 offset, unsigned int *nbytes, const char *buf,
 		 const int long_op)
@@ -534,7 +539,7 @@ int CIFSSMBWrite(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBLock(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBLock(const int xid, const struct cifsTconInfo *tcon,
 		const __u16 smb_file_id, const __u64 len,
 		const __u64 offset, const __u32 numUnlock,
 		const __u32 numLock, const __u32 lockType,
@@ -580,7 +585,7 @@ int CIFSSMBLock(const int xid, const struct smbTconInfo *tcon,
 }
 
 
-int CIFSSMBClose(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBClose(const int xid, const struct cifsTconInfo *tcon,
 		 int smb_file_id)
 {
 	int rc = 0;
@@ -610,7 +615,7 @@ int CIFSSMBClose(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBRename(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBRename(const int xid, const struct cifsTconInfo *tcon,
 		  const char *fromName, const char *toName,
 		  const struct nls_table *nls_codepage)
 {
@@ -678,7 +683,7 @@ int CIFSSMBRename(const int xid, const struct smbTconInfo *tcon,
 }
 
 
-int CIFSUnixCreateSymLink(const int xid, const struct smbTconInfo *tcon,
+int CIFSUnixCreateSymLink(const int xid, const struct cifsTconInfo *tcon,
 			  const char *fromName, const char *toName,
 			  const struct nls_table *nls_codepage)
 {
@@ -765,7 +770,7 @@ int CIFSUnixCreateSymLink(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSUnixCreateHardLink(const int xid, const struct smbTconInfo *tcon,
+int CIFSUnixCreateHardLink(const int xid, const struct cifsTconInfo *tcon,
 			   const char *fromName, const char *toName,
 			   const struct nls_table *nls_codepage)
 {
@@ -852,7 +857,7 @@ int CIFSUnixCreateHardLink(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSCreateHardLink(const int xid, const struct smbTconInfo *tcon,
+int CIFSCreateHardLink(const int xid, const struct cifsTconInfo *tcon,
 		       const char *fromName, const char *toName,
 		       const struct nls_table *nls_codepage)
 {
@@ -925,7 +930,7 @@ int CIFSCreateHardLink(const int xid, const struct smbTconInfo *tcon,
 }
 
 
-int CIFSSMBUnixQuerySymLink(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBUnixQuerySymLink(const int xid, const struct cifsTconInfo *tcon,
 			    const unsigned char *searchName,
 			    char *symlinkinfo, const int buflen,
 			    const struct nls_table *nls_codepage)
@@ -1008,7 +1013,7 @@ int CIFSSMBUnixQuerySymLink(const int xid, const struct smbTconInfo *tcon,
 
 
 
-int CIFSSMBQPathInfo(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 		     const unsigned char *searchName,
 		     FILE_ALL_INFO * pFindData,
 		     const struct nls_table *nls_codepage)
@@ -1086,7 +1091,7 @@ int CIFSSMBQPathInfo(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBUnixQPathInfo(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBUnixQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 			 const unsigned char *searchName,
 			 FILE_UNIX_BASIC_INFO * pFindData,
 			 const struct nls_table *nls_codepage)
@@ -1165,7 +1170,7 @@ int CIFSSMBUnixQPathInfo(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSFindSingle(const int xid, const struct smbTconInfo *tcon,
+int CIFSFindSingle(const int xid, const struct cifsTconInfo *tcon,
 		   const char *searchName, FILE_ALL_INFO * findData,
 		   const struct nls_table *nls_codepage)
 {
@@ -1239,7 +1244,7 @@ int CIFSFindSingle(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSFindFirst(const int xid, const struct smbTconInfo *tcon,
+int CIFSFindFirst(const int xid, const struct cifsTconInfo *tcon,
 		  const char *searchName, FILE_DIRECTORY_INFO * findData,
 		  T2_FFIRST_RSP_PARMS * findParms,
 		  const struct nls_table *nls_codepage, int *pUnicodeFlag,
@@ -1340,7 +1345,7 @@ int CIFSFindFirst(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSFindNext(const int xid, const struct smbTconInfo *tcon,
+int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 		 FILE_DIRECTORY_INFO * findData,
 		 T2_FNEXT_RSP_PARMS * findParms, const __u16 searchHandle,
 		 __u32 resumeKey, int *pUnicodeFlag, int *pUnixFlag)
@@ -1379,8 +1384,9 @@ int CIFSFindNext(const int xid, const struct smbTconInfo *tcon,
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
 	pSMB->SearchHandle = searchHandle;
 	findParms->SearchCount = 0;	/* set to zero in case of error */
-	pSMB->SearchCount = cpu_to_le16(CIFS_MAX_MSGSIZE / sizeof(FILE_DIRECTORY_INFO));  
-    /* test for Unix extensions */
+	pSMB->SearchCount =
+	    cpu_to_le16(CIFS_MAX_MSGSIZE / sizeof(FILE_DIRECTORY_INFO));
+	/* test for Unix extensions */
 	if (tcon->ses->capabilities & CAP_UNIX) {
 		pSMB->InformationLevel = cpu_to_le16(SMB_FIND_FILE_UNIX);
 		*pUnixFlag = TRUE;
@@ -1423,7 +1429,7 @@ int CIFSFindNext(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSGetDFSRefer(const int xid, const struct smbTconInfo *tcon,
+int CIFSGetDFSRefer(const int xid, struct cifsSesInfo *ses,
 		    const unsigned char *searchName,
 		    unsigned char **targetUNCs,
 		    int *number_of_UNC_in_array,
@@ -1435,17 +1441,28 @@ int CIFSGetDFSRefer(const int xid, const struct smbTconInfo *tcon,
 	int rc = 0;
 	int bytes_returned;
 	int name_len;
+	*number_of_UNC_in_array = 0;
+	*targetUNCs = NULL;
 
 	cFYI(1, ("\nIn GetDFSRefer the path %s", searchName));
-	rc = smb_init(SMB_COM_TRANSACTION2, 15, tcon, (void **) &pSMB,
+	if (ses == NULL)
+		return -ENODEV;
+
+	rc = smb_init(SMB_COM_TRANSACTION2, 15, 0, (void **) &pSMB,
 		      (void **) &pSMBr);
 	if (rc)
 		return rc;
 
-	/* BB prepend UNC path to real local mount/share relative path - 
-	   and also we really should connect to IPC$ here and use that tid instead of our file share tid BB */
-
-	if (pSMB->hdr.Flags2 & SMBFLG2_UNICODE) {
+	pSMB->hdr.Tid = ses->ipc_tid;
+	pSMB->hdr.Uid = ses->Suid;
+	if (ses->capabilities & CAP_STATUS32) {
+		pSMB->hdr.Flags2 |= SMBFLG2_ERR_STATUS;
+	}
+	if (ses->capabilities & CAP_DFS) {
+		pSMB->hdr.Flags2 |= SMBFLG2_DFS;
+	}
+	if (ses->capabilities & CAP_UNICODE) {
+		pSMB->hdr.Flags2 |= SMBFLG2_UNICODE;
 		name_len =
 		    cifs_strtoUCS((UniChar *) pSMB->RequestFileName,
 				  searchName, 530
@@ -1478,12 +1495,12 @@ int CIFSGetDFSRefer(const int xid, const struct smbTconInfo *tcon,
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = TRANS2_GET_DFS_REFERRAL;
-	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
+	pSMB->ByteCount = pSMB->TotalParameterCount + 3 /* pad */ ;
 	pSMB->MaxReferralLevel = 3;
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
 	pSMB->ByteCount = cpu_to_le16(pSMB->ByteCount);
 
-	rc = SendReceive(xid, tcon->ses, (struct smb_hdr *) pSMB,
+	rc = SendReceive(xid, ses, (struct smb_hdr *) pSMB,
 			 (struct smb_hdr *) pSMBr, &bytes_returned, 0);
 	if (rc) {
 		cFYI(1, ("\nSend error in GetDFSRefer = %d\n", rc));
@@ -1497,7 +1514,7 @@ int CIFSGetDFSRefer(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBQFSInfo(const int xid, const struct smbTconInfo *tcon,
+int CIFSSMBQFSInfo(const int xid, const struct cifsTconInfo *tcon,
 		   struct statfs *FSData,
 		   const struct nls_table *nls_codepage)
 {
@@ -1573,7 +1590,7 @@ int CIFSSMBQFSInfo(const int xid, const struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBQFSAttributeInfo(int xid, struct smbTconInfo *tcon,
+int CIFSSMBQFSAttributeInfo(int xid, struct cifsTconInfo *tcon,
 			    const struct nls_table *nls_codepage)
 {
 /* level 0x105  SMB_QUERY_FILE_SYSTEM_INFO */
@@ -1635,7 +1652,7 @@ int CIFSSMBQFSAttributeInfo(int xid, struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBQFSDeviceInfo(int xid, struct smbTconInfo *tcon,
+int CIFSSMBQFSDeviceInfo(int xid, struct cifsTconInfo *tcon,
 			 const struct nls_table *nls_codepage)
 {
 /* level 0x104 SMB_QUERY_FILE_SYSTEM_INFO */
@@ -1698,7 +1715,7 @@ int CIFSSMBQFSDeviceInfo(int xid, struct smbTconInfo *tcon,
 	return rc;
 }
 
-int CIFSSMBQFSUnixInfo(int xid, struct smbTconInfo *tcon,
+int CIFSSMBQFSUnixInfo(int xid, struct cifsTconInfo *tcon,
 		       const struct nls_table *nls_codepage)
 {
 /* level 0x200  SMB_QUERY_CIFS_UNIX_INFO */
@@ -1761,7 +1778,7 @@ int CIFSSMBQFSUnixInfo(int xid, struct smbTconInfo *tcon,
 }
 
 
-int CIFSSMBSetEOF(int xid, struct smbTconInfo *tcon, char *fileName,
+int CIFSSMBSetEOF(int xid, struct cifsTconInfo *tcon, char *fileName,
 		  __u64 size, const struct nls_table *nls_codepage)
 {
 /* level 0x104 T2SetPathInfo - we can not use write of zero bytes trick to set file size due to need for large file support*/
@@ -1837,7 +1854,7 @@ int CIFSSMBSetEOF(int xid, struct smbTconInfo *tcon, char *fileName,
 	return rc;
 }
 
-int CIFSSMBSetAllocationSize(int xid, struct smbTconInfo *tcon,
+int CIFSSMBSetAllocationSize(int xid, struct cifsTconInfo *tcon,
 			     char *fileName, __u64 size,
 			     const struct nls_table *nls_codepage)
 {
@@ -1918,7 +1935,7 @@ int CIFSSMBSetAllocationSize(int xid, struct smbTconInfo *tcon,
 }
 
 
-int CIFSSMBSetTimes(int xid, struct smbTconInfo *tcon, char *fileName,
+int CIFSSMBSetTimes(int xid, struct cifsTconInfo *tcon, char *fileName,
 		    FILE_BASIC_INFO * data,
 		    const struct nls_table *nls_codepage)
 {
@@ -1992,7 +2009,7 @@ int CIFSSMBSetTimes(int xid, struct smbTconInfo *tcon, char *fileName,
 	return rc;
 }
 
-int CIFSSMBUnixSetPerms(const int xid, struct smbTconInfo *tcon,
+int CIFSSMBUnixSetPerms(const int xid, struct cifsTconInfo *tcon,
 			char *fileName, __u64 mode, __u64 uid, __u64 gid,
 			const struct nls_table *nls_codepage)
 {
