@@ -55,26 +55,26 @@ void _FreeXid(unsigned int xid)
 	up(&GlobalMid_Sem);
 }
 
-struct smbSesInfo *sesInfoAlloc(void)
+struct cifsSesInfo *sesInfoAlloc(void)
 {
-	struct smbSesInfo *ret_buf;
+	struct cifsSesInfo *ret_buf;
 
 	ret_buf =
-	    (struct smbSesInfo *) kmalloc(sizeof(struct smbSesInfo),
-					  GFP_KERNEL);
+	    (struct cifsSesInfo *) kmalloc(sizeof(struct cifsSesInfo),
+					   GFP_KERNEL);
 	if (ret_buf) {
-		memset(ret_buf, 0, sizeof(struct smbSesInfo));
+		memset(ret_buf, 0, sizeof(struct cifsSesInfo));
 		atomic_inc(&sesInfoAllocCount);
-		list_add(&ret_buf->smbSessionList, &GlobalSMBSessionList);
+		list_add(&ret_buf->cifsSessionList, &GlobalSMBSessionList);
 		init_MUTEX(&ret_buf->sesSem);
 	}
 	return ret_buf;
 }
 
-void sesInfoFree(struct smbSesInfo *buf_to_free)
+void sesInfoFree(struct cifsSesInfo *buf_to_free)
 {
 	atomic_dec(&sesInfoAllocCount);
-	list_del(&buf_to_free->smbSessionList);
+	list_del(&buf_to_free->cifsSessionList);
 	if (buf_to_free->serverOS)
 		kfree(buf_to_free->serverOS);
 	if (buf_to_free->serverDomain)
@@ -84,26 +84,26 @@ void sesInfoFree(struct smbSesInfo *buf_to_free)
 	kfree(buf_to_free);
 }
 
-struct smbTconInfo *tconInfoAlloc(void)
+struct cifsTconInfo *tconInfoAlloc(void)
 {
-	struct smbTconInfo *ret_buf;
+	struct cifsTconInfo *ret_buf;
 	ret_buf =
-	    (struct smbTconInfo *) kmalloc(sizeof(struct smbTconInfo),
-					   GFP_KERNEL);
+	    (struct cifsTconInfo *) kmalloc(sizeof(struct cifsTconInfo),
+					    GFP_KERNEL);
 	if (ret_buf) {
-		memset(ret_buf, 0, sizeof(struct smbTconInfo));
+		memset(ret_buf, 0, sizeof(struct cifsTconInfo));
 		atomic_inc(&tconInfoAllocCount);
-		list_add(&ret_buf->smbConnectionList,
+		list_add(&ret_buf->cifsConnectionList,
 			 &GlobalTreeConnectionList);
 		init_MUTEX(&ret_buf->tconSem);
 	}
 	return ret_buf;
 }
 
-void tconInfoFree(struct smbTconInfo *buf_to_free)
+void tconInfoFree(struct cifsTconInfo *buf_to_free)
 {
 	atomic_dec(&tconInfoAllocCount);
-	list_del(&buf_to_free->smbConnectionList);
+	list_del(&buf_to_free->cifsConnectionList);
 	if (buf_to_free->nativeFileSystem)
 		kfree(buf_to_free->nativeFileSystem);
 	kfree(buf_to_free);
@@ -147,7 +147,7 @@ void buf_release(void *buf_to_free)
 
 void header_assemble(struct smb_hdr *buffer,
 		     char smb_command /* command */ ,
-		     const struct smbTconInfo *treeCon, int word_count
+		     const struct cifsTconInfo *treeCon, int word_count
 		     /* length of fixed section (word count) in two byte units  */
     )
 {
